<template>
  <div class="IndexHeader">
    <div class="header" :class="{ showBox: isShow, disOpacity: !opacity }">
      <!-- 右侧 -->
      <div class="left">
        <img class="logo" src="/images/index/LOGO.png" alt="" />
        <div class="title">工业物联网平台</div>
        <div class="label"><router-link to="/">首页</router-link></div>
        <div class="label">云服务</div>
        <div class="label">
          <router-link to="/equipmentManagement">管理中心</router-link>
        </div>
        <div class="label">应用商城</div>
      </div>

      <!-- 左侧 -->
      <div class="right">
        <el-input
          placeholder="请输入关键词"
          v-model="keyWord"
          @focus="showInputBox(true)"
        >
          <div class="iconList" slot="suffix">
            <i class="search iconfont" v-if="!isShow">&#xe607;</i>
            <i class="search iconfont" v-if="isShow">&#xe607;</i>
            <i class="del iconfont" v-if="isShow" @click="showInputBox(false)"
              >&#xe60f;</i
            >
          </div>
        </el-input>

        <!-- 未登录情况 -->
        <div class="headerLogin" v-if="!userInfo">
          <router-link to="/login"> 登录</router-link>
        </div>
        <div class="register" v-if="!userInfo">
          <router-link to="/register"> 免费注册 </router-link>
        </div>

        <!-- 已登录情况 -->
        <img
          class="userImg"
          src="/images/index/默认头像-01.png"
          alt=""
          v-if="userInfo"
          @mouseenter="showUserBox"
          @mouseleave="hiddenUserBox"
        />
      </div>
    </div>

    <!-- 用户下拉框 -->
    <div
      class="userBox"
      v-if="userInfo && isShowUserBox"
      @mouseenter="showUserBox"
      @mouseleave="hiddenUserBox"
    >
      <div class="userName">{{ userInfo.username }}</div>
      <ul>
        <li class="money">
          <div class="label">余额</div>
          <div class="content">
            <span class="button">充值</span>
            <span class="number">￥4900.82</span>
          </div>
        </li>

        <li class="personal">
          <div class="label">个人中心</div>
          <div class="content">
            <span class="iconfont">&#xe605;</span> 已实名认证
          </div>
        </li>

        <li>
          <div class="label">订单管理</div>
        </li>

        <li>
          <div class="label">产品续费</div>
        </li>

        <li>
          <div class="label">未读消息</div>
        </li>

        <li>
          <div class="label">未支付订单</div>
        </li>

        <li>
          <div class="label">管理中心</div>
        </li>
      </ul>
      <div class="logOut" @click="logOut">退出登录</div>
    </div>

    <!-- 输入下拉框 -->
    <div class="inputBox" v-if="isShowBox">
      <div class="hotKey">
        <div class="title">热门搜索</div>
        <ul class="keyCard">
          <li class="keyItem" v-for="(item, index) in hotKeyArr" :key="index">
            {{ item }}
          </li>
        </ul>
      </div>

      <div class="historyKey">
        <div class="title colorLight">历史搜索</div>

        <ul class="keyCard">
          <li
            class="keyItem"
            v-for="(item, index) in historyKeyArr"
            :key="index"
          >
            {{ item }}
          </li>
        </ul>
      </div>
    </div>

    <!-- 遮罩层 -->
    <div class="mask" v-if="isShowBox"></div>
  </div>
</template>

<script>
import { logout } from "@/api/login";

export default {
  props: {
    opacity: {
      type: Boolean,
      default: true,
    },
  },
  name: "Header",
  created() {
    //尝试从session中拿用户信息
    this.userInfo = JSON.parse(sessionStorage.getItem("userInfo"));
    /*  document.addEventListener("click", () => {
      this.showUserBox = false;
    }); */
  },
  data() {
    return {
      keyWord: "", //输入框内容
      isShow: false, //显示下拉框
      hotKeyArr: ["算法", "智能AI", "云服务", "管理中心", "实时音视频", "短信"], //热门关键词
      historyKeyArr: ["云服务", "算法", "管理服务", "应用"], //历史关键词
      isShowBox: false, //输入下拉框
      userInfo: null, //用户信息
      isShowUserBox: false, //用户信息弹层
      UserTimer: null, // 控制弹层的定时器
    };
  },
  methods: {
    // 控制输入框box
    showInputBox(toggle) {
      this.isShow = toggle;
      this.isShowBox = toggle;
      this.$emit("showInputBox", toggle);
    },

    //控制用户信息box
    showUserBox() {
      if (this.UserTimer) {
        clearTimeout(this.UserTimer);
        this.UserTimer = null;
      }
      this.isShowUserBox = true;
    },
    hiddenUserBox() {
      const _this = this;
      this.UserTimer = setTimeout(() => {
        _this.isShowUserBox = false;
      }, 100);
    },

    logOut() {
      logout().then(() => {
        sessionStorage.removeItem("loginedInfo");
        sessionStorage.removeItem("expires_in");
        sessionStorage.removeItem("userInfo");
        this.$router.push({
          path: "/login",
        });
        this.$notify({
          title: "提示",
          type: "success",
          message: "退出成功！",
          duration: 2500,
          offset: 57,
        });
      });
    },
  },
};
</script>

<style lang="scss" scoped>
.header {
  display: flex;
  justify-content: space-between;
  align-items: center;
  height: 62px;
  width: 100%;
  min-width: 1280px;
  background-color: rgba(255, 255, 255, 0.25);
  color: #fff;
  font-size: 14px;

  .left {
    display: flex;
    align-items: center;

    .logo {
      margin: 0 7px 0 20px;
    }

    .title {
      margin-right: 10px;
    }

    .label {
      margin: 0 20px;
      cursor: pointer;
    }
  }

  .right {
    position: relative;
    display: flex;
    align-items: center;

    .el-input ::v-deep {
      input {
        height: 62px;
        width: 180px;
        background-color: rgba(255, 255, 255, 0.5);
        border: none;
        border-radius: 0;
        color: #fff;

        &::-webkit-input-placeholder {
          color: #fff;
        }
      }

      .el-input__suffix {
        padding-top: 23px;
        padding-right: 23px;
      }

      .search {
        color: #fff;
        cursor: pointer;
      }
    }

    .headerLogin {
      flex-shrink: 0;
      width: 62px;
      height: 62px;
      text-align: center;
      line-height: 62px;
      background-color: rgb(64, 97, 202);
      cursor: pointer;
    }

    .register {
      flex-shrink: 0;
      width: 96px;
      height: 62px;
      text-align: center;
      line-height: 62px;
      background: #0065ff;
      cursor: pointer;
    }

    .userImg {
      height: 48px;
      width: 48px;
      margin: 0 20px;
    }
  }

  &:hover,
  &.showBox,
  &.disOpacity {
    background-color: #fff;

    .left {
      .title {
        color: #3d3d3d;
        font-weight: 700;
      }

      .label {
        color: #3d3d3d;
      }
    }
    .right {
      .el-input ::v-deep {
        input {
          background-color: rgba(245, 247, 250, 0.45);
          color: #3d3d3d;

          &::-webkit-input-placeholder {
            color: #999999;
          }
        }

        .search {
          color: rgb(32, 119, 254);
        }
      }

      .headerLogin {
        background-color: #fff;
        color: #3d3d3d;
      }
    }
  }

  &.showBox .right .el-input {
    position: absolute;
    z-index: 4;
    top: 0;
    right: 158px;
    width: 300px;
    background-color: #fff;
    ::v-deep input {
      width: 300px;
      background-color: #fff;
    }

    .del {
      color: rgb(32, 119, 254);
      margin-left: 30px;
      cursor: pointer;
    }
  }
}

.inputBox {
  box-sizing: border-box;
  position: absolute;
  top: 62px;
  right: 158px;
  padding: 12px 20px 8px 20px;
  width: 300px;
  background-color: #fff;
  border-top: 1px solid rgb(204, 204, 204);
  z-index: 4;

  .hotKey,
  .historyKey {
    margin-top: 12px;

    .title {
      margin-bottom: 16px;
      font-weight: 700;
      font-size: 14px;
    }

    .keyCard {
      display: flex;
      flex-wrap: wrap;

      .keyItem {
        display: inline-block;
        margin-right: 12px;
        margin-bottom: 12px;
        padding: 5px 12px;
        color: #5c7399;
        background-color: #e4e9f1;
        font-size: 12px;
        cursor: pointer;
      }
    }
  }
}

.mask {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: #000000;
  opacity: 0.2;
  z-index: 3;
}

.userBox {
  box-sizing: border-box;
  position: absolute;
  z-index: 3;
  right: 20px;
  top: 64px;
  padding: 0 20px;
  width: 240px;
  height: 427px;
  background-color: #fff;
  box-shadow: 0px 4px 12px rgba(96, 100, 106, 0.12);
  border-radius: 4px;

  .userName {
    margin: 20px 0;
    font-weight: bold;
    font-size: 18px;
  }

  ul {
    height: 300px;
    border-top: 1px solid #e9ebee;
    border-bottom: 1px solid #e9ebee;

    li {
      display: flex;
      justify-content: space-between;
      margin: 20px 0;
      font-size: 14px;

      .label {
        cursor: pointer;
        &:hover {
          color: #0065ff;
        }
      }

      &.personal .content {
        color: #36b24a;
      }

      &.money .content {
        color: #666666;

        .button {
          display: inline-block;
          margin-right: 10px;
          width: 34px;
          height: 24px;
          text-align: center;
          line-height: 24px;
          font-size: 12px;
          border: 1px solid #ff6a00;
          color: #ff6a00;
        }
      }
    }
  }

  .logOut {
    margin-top: 20px;
    font-size: 16px;
    color: #0065ff;
    cursor: pointer;
  }
}
</style>